==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNullValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueNullValueFluent<A extends ValueNullValueFluent<A>> extends BaseFluent<A>{
  public ValueNullValueFluent() {
  }
  public ValueNullValueFluent(ValueNullValue instance) {
    instance = (instance != null ? instance : new ValueNullValue());

    if (instance != null) {
      this.withNullValue(instance.getNullValue());
      this.withNullValue(instance.getNullValue());
    }
  }
  private NullValue nullValue;
  public NullValue getNullValue() {
    return this.nullValue;
  }
  public A withNullValue(NullValue nullValue) {
    this.nullValue=nullValue; return (A) this;
  }
  public boolean hasNullValue() {
    return this.nullValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueNullValueFluent that = (ValueNullValueFluent) o;
    if (!java.util.Objects.equals(nullValue, that.nullValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(nullValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nullValue != null) { sb.append("nullValue:"); sb.append(nullValue); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNullValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueNullValueFluent<A extends ValueNullValueFluent<A>> extends BaseFluent<A>{
  public ValueNullValueFluent() {
  }
  
  public ValueNullValueFluent(ValueNullValue instance) {
    this.copyInstance(instance);
  }
  private NullValue nullValue;
  
  protected void copyInstance(ValueNullValue instance) {
    instance = (instance != null ? instance : new ValueNullValue());
  
    if (instance != null) {
        this.withNullValue(instance.getNullValue());
        this.withNullValue(instance.getNullValue());
      }
  }
  
  public NullValue getNullValue() {
    return this.nullValue;
  }
  
  public A withNullValue(NullValue nullValue) {
    this.nullValue=nullValue; return (A) this;
  }
  
  public boolean hasNullValue() {
    return this.nullValue != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueNullValueFluent that = (ValueNullValueFluent) o;
    if (!java.util.Objects.equals(nullValue, that.nullValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(nullValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nullValue != null) { sb.append("nullValue:"); sb.append(nullValue); }
    sb.append("}");
    return sb.toString();
  }
  

}
